import { ModuleClient } from "../../shared";
import { UploadMetadataOperation, PlanUploadMetadataOperation, CreateNftOperation, FindNftByMintOperation, UpdateNftOperation, FindNftsByOwnerOperation, FindNftsByMintListOperation, FindNftsByCreatorOperation, FindNftsByCandyMachineOperation, } from './operations';
export class NftClient extends ModuleClient {
    async findNftByMint(mint) {
        return this.metaplex.execute(new FindNftByMintOperation(mint));
    }
    async findNftsByMintList(mints) {
        return this.metaplex.execute(new FindNftsByMintListOperation(mints));
    }
    async findNftsByOwner(owner) {
        return this.metaplex.execute(new FindNftsByOwnerOperation(owner));
    }
    async findNftsByCreator(creator, position = 1) {
        return this.metaplex.execute(new FindNftsByCreatorOperation({ creator, position }));
    }
    async findNftsByCandyMachine(candyMachine, version) {
        return this.metaplex.execute(new FindNftsByCandyMachineOperation({ candyMachine, version }));
    }
    async uploadMetadata(input) {
        return this.metaplex.execute(new UploadMetadataOperation(input));
    }
    async planUploadMetadata(input) {
        return this.metaplex.execute(new PlanUploadMetadataOperation(input));
    }
    async createNft(input) {
        const operation = new CreateNftOperation(input);
        const createNftOutput = await this.metaplex.execute(operation);
        const nft = await this.findNftByMint(createNftOutput.mint.publicKey);
        return { ...createNftOutput, nft };
    }
    async updateNft(nft, input) {
        const operation = new UpdateNftOperation({ ...input, nft });
        const updateNftOutput = await this.metaplex.execute(operation);
        const updatedNft = await this.findNftByMint(nft.mint);
        return { ...updateNftOutput, nft: updatedNft };
    }
}
//# sourceMappingURL=NftClient.js.map